'use client'

import React from 'react'
import { motion } from 'framer-motion'
import { Users, Award, Coffee, Code } from 'lucide-react'

interface Stats {
  clients: number
  projects: number
  coffeeConsumed: number
  linesOfCode: number
}

interface AboutUsStatsProps {
  stats?: Stats
}

const defaultStats: Stats = {
  clients: 0,
  projects: 0,
  coffeeConsumed: 0,
  linesOfCode: 0
}

const AboutUsStatsSection: React.FC<AboutUsStatsProps> = ({ stats = defaultStats }) => {
  return (
    <section className="aus-stats py-16 px-4">
      <div className="max-w-6xl mx-auto grid grid-cols-2 md:grid-cols-4 gap-8">
        <StatItem icon={Users} number={stats.clients} label="Happy Clients" delay={0.1} />
        <StatItem icon={Award} number={stats.projects} label="Projects Completed" delay={0.2} />
        <StatItem icon={Coffee} number={stats.coffeeConsumed} label="Cups of Coffee" delay={0.3} />
        <StatItem icon={Code} number={stats.linesOfCode} label="Lines of Code" delay={0.4} />
      </div>
    </section>
  )
}

interface StatItemProps {
  icon: React.ElementType
  number: number
  label: string
  delay: number
}

const StatItem: React.FC<StatItemProps> = ({ icon: Icon, number, label, delay }) => (
  <motion.div 
    className="aus-stat text-center"
    initial={{ opacity: 0, y: 20 }}
    animate={{ opacity: 1, y: 0 }}
    transition={{ duration: 0.5, delay }}
  >
    <Icon className="aus-stat-icon w-12 h-12 text-blue-500 mx-auto mb-2" />
    <h3 className="aus-stat-number text-3xl font-bold">{number}+</h3>
    <p className="aus-stat-label text-gray-600">{label}</p>
  </motion.div>
)

export default AboutUsStatsSection